# SPDX-License-Identifier: CECILL-C

module SpeechDatasets

using JSON
import AudioSources
using SpeechFeatures
import MLUtils

export
    # ManifestItem
    Recording,
    Annotation,
    load,

    # Manifest interface
    writemanifest,
    readmanifest,

    # Lexicon
    CMUDICT,
    TIMITDICT,
    MFAFRDICT,

    # Builder
    DatasetBuilder,
    get_kwargs,
    get_dataset_kwargs,
    get_nametype,
    download,
    prepare,

    # Dataset
    SpeechDatasetInfos,
    SpeechDataset,
    dataset

const corpora_file = joinpath(@__DIR__, "corpora", "corpora.json")
const corpora_names = map(c -> c["name"], JSON.parsefile(corpora_file))

include("manifest_item.jl")
include("manifest_io.jl")
include("builder.jl")
include("dataset.jl")

# Supported corpora
include.("corpora/".*filter(contains(r"\.jl$"), readdir(joinpath(@__DIR__, "corpora"))))
include("lexicons.jl")

# declare all supported builders
declareBuilder.(get_nametype.(corpora_names))

end
